GoConqr hat ein neues Design! Sag uns, wie es dir gefällt.

Karteikarten

untitled 2

lola_smily Englisch 5,0Durchschnittliche Bewertung 5,0 von 5 (2 Bewertungen) 162 Karten 2.277 Aufrufe

untitled 2

Karten in diesem Stapel (162)

  1. 1—Acetylcholine
    -muscarinic receptor agonist
    Acetylcholine -muscarinic receptor agonist
  2. 2—Metacholine
    - muscarinic receptor agonist
    - modification of the ethylene bridge
    - S(+) equipotent to ACH
    - beta methyl substitution => more selective to Muscarininc receptor
    - more resistant to AChE => slow hydrolysis
    Metacholine - muscarinic receptor agonist - modification of the ethylene bridge - S(+) equipotent to ACH - beta methyl substitution =>...
  3. 3—Carbachol
    -muscarinic receptor agonist
    - modification of the acetoxy group
    - converting ester to carbamate
    - similar ACh potency, same profile
    -hydrolysis by AChE
    Carbachol -muscarinic receptor agonist - modification of the acetoxy group - converting ester to carbamate - similar ACh potency, same pr...
  4. 4—Bethanechol
    - muscarinic receptor agonist
    - beta methyl substitution
    - potent and selective Muscarinic agonist
    -S(+) more potent
    Bethanechol - muscarinic receptor agonist - beta methyl substitution - potent and selective Muscarinic agonist -S(+) more potent
  5. 5—choline ethyl ether
    - muscarinic receptor agonist
    - exception to the classical SAR of muscarinic activity
    choline ethyl ether - muscarinic receptor agonist - exception to the classical SAR of muscarinic activity
  6. 6—alkyl amino ketones
    - muscarinic receptor agonist
    - exception to the classical SAR of muscarinic activity
    alkyl amino ketones - muscarinic receptor agonist - exception to the classical SAR of muscarinic activity
  7. 7—L(+)- Muscarine ChlorideL(+)- Muscarine Chloride
  8. 8—epimuscarineepimuscarine
  9. 9—pilocarpine
    - alkaloid, produced from Pilocarpus jaborandi
    - Potent muscarinic agonist
    - chemically unstable => ring opening
    pilocarpine - alkaloid, produced from Pilocarpus jaborandi - Potent muscarinic agonist - chemically unstable => ring opening
  10. 10—pilocarpic acid
    - inactive
    - product of hydrolysis of pilocarpine
    pilocarpic acid - inactive - product of hydrolysis of pilocarpine
  11. 11—isopilocarpine
    - epimerization of pilocarpine
    - inactive product
    isopilocarpine - epimerization of pilocarpine - inactive product
  12. 12—Physostigmine
    -indirectly acting parasympathomimetics
    - reversible AChE
    - 3ary alkaloid obtained from the Calabar Bean, Physostigma venosum
    - exhibits high affinity to AChE of 10^-9 to carbachol of 10^-4
    -used to treat glaucoma and over dose of anticholinergic
    -light sensitive
    -undergoes hydrolysis in aqueous solutions
    Physostigmine -indirectly acting parasympathomimetics - reversible AChE - 3ary alkaloid obtained from the Calabar Bean, Physostigma venos...
  13. 13—eseroline
    inactive degradation product of physostigmmine in aqueous solutions
    eseroline inactive degradation product of physostigmmine in aqueous solutions
  14. 14—rubreserine
    -inactive degradation product of physostigmmine in aqueous solutions
    - red color
    rubreserine -inactive degradation product of physostigmmine in aqueous solutions - red color
  15. 15—neostigmine
    -indirectly acting parasympathomimetics
    - reversible AChE
    synthetic
    ionized
    -indicated for Myastenia Gravis
    neostigmine -indirectly acting parasympathomimetics - reversible AChE synthetic ionized -indicated for Myastenia Gravis
  16. 16—pyridostigmine
    -indirectly acting parasympathomimetics
    - reversible AChE
    synthetic
    ionized
    -indicated for Myastenia Gravis
    pyridostigmine -indirectly acting parasympathomimetics - reversible AChE synthetic ionized -indicated for Myastenia Gravis
  17. 17—donepezil hydrochloride
    -indirectly acting parasympathomimetics
    - reversible AChE
    - lack hepatotoxicity
    - used for Alzheimer's disease
    donepezil hydrochloride -indirectly acting parasympathomimetics - reversible AChE - lack hepatotoxicity - used for Alzheimer's disease
  18. 18—tacrine
    indirectly acting parasympathomimetics
    - reversible AChE
    - cause hepatotoxicity
    - used for Alzheimer's disease
    tacrine indirectly acting parasympathomimetics - reversible AChE - cause hepatotoxicity - used for Alzheimer's disease
  19. 19—rivastigmine
    indirectly acting parasympathomimetics
    - reversible AChE
    - lack hepatotoxicity
    - used for Alzheimer's disease
    rivastigmine indirectly acting parasympathomimetics - reversible AChE - lack hepatotoxicity - used for Alzheimer's disease
  20. 20—Edrophonium
    -used for diagnostic purposes
    - improve Myastenia Gravis
    -worsen cholinergic chrisis
    Edrophonium -used for diagnostic purposes - improve Myastenia Gravis -worsen cholinergic chrisis
  21. 21—Malathion
    irreversible AChEi
    organophosphate
    thio group
    Malathion irreversible AChEi organophosphate thio group
  22. 22—parathion
    irreversible AChEi
    organophosphate
    thio group
    low Anti-AChE activity
    parathion irreversible AChEi organophosphate thio group low Anti-AChE activity
  23. 23—sarin
    irreversible AChEi
    organophosphate
    sarin irreversible AChEi organophosphate
  24. 24—paraoxon
    irreversible AChEi
    organophosphate
    oxo group
    high Anti-AChE activity
    paraoxon irreversible AChEi organophosphate oxo group high Anti-AChE activity
  25. 25—echothiophate iodide
    irreversible AChEi
    organophosphate
    ionized => clnical application for glaucoma
    echothiophate iodide irreversible AChEi organophosphate ionized => clnical application for glaucoma
  26. 26—oxime
    reactivation of AChE
    oxime reactivation of AChE
  27. 27—Pralidoxime chloride (2 -PAM)
    reactivation of AChE
    Pralidoxime chloride (2 -PAM) reactivation of AChE
  28. 28—obidoxime
    reactivation of AChE
    obidoxime reactivation of AChE
  29. 29—diacetylmonoxime
    reactivation of AChE
    diacetylmonoxime reactivation of AChE
  30. 30—atropine
    parasympatholytics
    muscarine receptor antagonist
    alkaloid obtained from atropa belladonna
    atropine also found in datura stramonium
    atropine parasympatholytics muscarine receptor antagonist alkaloid obtained from atropa belladonna atropine also found in datura stramonium
  31. 31—scopolamine
    parasympatholytics
    muscarine receptor antagonist
    alkaloid obtained from atropa belladonna
    aslo found in Hyascyamus niger
    scopolamine parasympatholytics muscarine receptor antagonist alkaloid obtained from atropa belladonna aslo found in Hyascyamus niger
  32. 32—glycopyrrolate
    -antiholinergic
    -amino alcohol ester
    -ionized, exert effect locally in GI
    glycopyrrolate -antiholinergic -amino alcohol ester -ionized, exert effect locally in GI
  33. 33—propantheline
    antiholinergic
    -amino alcohol ester
    -ionized, exert effect locally in GI
    propantheline antiholinergic -amino alcohol ester -ionized, exert effect locally in GI
  34. 34—clinidium
    antiholinergic
    -amino alcohol ester
    -ionized, exert effect locally in GI
    clinidium antiholinergic -amino alcohol ester -ionized, exert effect locally in GI
  35. 35—ipratronium
    antiholinergic
    -amino alcohol ester
    -ionized, exert effect locally in GI
    ipratronium antiholinergic -amino alcohol ester -ionized, exert effect locally in GI
  36. 36—flavoxate
    antiholinergic
    -amino alcohol ester
    -ionized, exert effect locally in GI
    flavoxate antiholinergic -amino alcohol ester -ionized, exert effect locally in GI
  37. 37—oxyphencyclimine
    anticholinergic
    amino alcohol ester
    3ary amine, used for Parkinson treatment
    systemic, can cross BBB
    oxyphencyclimine anticholinergic amino alcohol ester 3ary amine, used for Parkinson treatment systemic, can cross BBB
  38. 38—procyclidine
    anticholinergic
    amino alcohol
    3ary amine, systemic effect
    procyclidine anticholinergic amino alcohol 3ary amine, systemic effect
  39. 39—trihexyphenidyl
    anticholinergic
    amino alcohol
    3ary amine, systemic effect
    trihexyphenidyl anticholinergic amino alcohol 3ary amine, systemic effect
  40. 40—benztropine
    anticholinergic
    amino ethers
    benztropine anticholinergic amino ethers
  41. 41—orphenadrine
    anticholinergic
    amino ether
    antihistaminic
    anticholinergic> antihistaminic
    orphenadrine anticholinergic amino ether antihistaminic anticholinergic> antihistaminic
  42. 42—pirenzepine
    - selective M1 receptor antagonist
    - they are competitive antagonists
    -have antispasmodic effects
    -produce mydriasis
    -antisecretory:
    -decrease gastric secretions
    -decrease saliva secretions
    -decrease bronchial secretions
    pirenzepine - selective M1 receptor antagonist - they are competitive antagonists -have antispasmodic effects -produce mydriasis -antisec...
  43. 43—telenzepine
    selective M1 receptor antagonist
    - they are competitive antagonists
    -have antispasmodic effects
    -produce mydriasis
    -antisecretory:
    -decrease gastric secretions
    -decrease saliva secretions
    -decrease bronchial secretions
    telenzepine selective M1 receptor antagonist - they are competitive antagonists -have antispasmodic effects -produce mydriasis -antisecre...
  44. 44—hexamethonium
    - ganglionic blocking agent
    - bisquaternary ammonium
    -MOA: they block autonomic ganglia => inhibit ganglionic transmission
    - main therapeutic indication: antihypertensive
    hexamethonium - ganglionic blocking agent - bisquaternary ammonium -MOA: they block autonomic ganglia => inhibit ganglionic transmissi...
  45. 45—trimethophan
    ganglionic blocking agent
    - sulfonium
    -MOA: they block autonomic ganglia => inhibit ganglionic transmission
    - main therapeutic indication: antihypertensive
    trimethophan ganglionic blocking agent - sulfonium -MOA: they block autonomic ganglia => inhibit ganglionic transmission - main therap...
  46. 46—pentolinium
    ganglionic blocking agent
    - bisquaternary ammonium
    -MOA: they block autonomic ganglia => inhibit ganglionic transmission
    - main therapeutic indication: antihypertensive
    pentolinium ganglionic blocking agent - bisquaternary ammonium -MOA: they block autonomic ganglia => inhibit ganglionic transmission -...
  47. 47—mecamylamine
    ganglionic blocking agent
    - secondary amines
    -MOA: they block autonomic ganglia => inhibit ganglionic transmission
    - main therapeutic indication: antihypertensive
    mecamylamine ganglionic blocking agent - secondary amines -MOA: they block autonomic ganglia => inhibit ganglionic transmission - main...
  48. 48—pempidine
    ganglionic blocking agent
    - tertiary amine
    -MOA: they block autonomic ganglia => inhibit ganglionic transmission
    - main therapeutic indication: antihypertensive
    pempidine ganglionic blocking agent - tertiary amine -MOA: they block autonomic ganglia => inhibit ganglionic transmission - main ther...
  49. 49—succinylcholine chloride
    - depolarizing NMJ blocker
    - produce a 2 phase block
    phase 1: stimulation
    phase 2: depression
    block by receptor desensitization
    - therapeutic use : muscle relaxation
    - reversal of effects of depolarizing : give antagonist to sensitize the receptor
    succinylcholine chloride - depolarizing NMJ blocker - produce a 2 phase block phase 1: stimulation phase 2: depression block by receptor ...
  50. 50—tubocurarine
    - non depolarizing NMJ blocker
    - cc: benzylisoquinoline
    - they are competitive receptor antagonist
    - all are ionized
    - lack CNS side effect
    - therapeutic use: muscle relaxation
    - reversal of effects of non depolarizing: AChI
    tubocurarine - non depolarizing NMJ blocker - cc: benzylisoquinoline - they are competitive receptor antagonist - all are ionized - lack ...
  51. 51—atracurium besylate
    - non depolarizing NMJ blocker
    - cc: benzylisoquinoline
    - they are competitive receptor antagonist
    - all are ionized
    - Exception: CNS side effects
    - therapeutic use: muscle relaxation
    - reversal of effects of non depolarizing: AChI
    atracurium besylate - non depolarizing NMJ blocker - cc: benzylisoquinoline - they are competitive receptor antagonist - all are ionized ...
  52. 52—mivacurium chloride
    non depolarizing NMJ blocker
    - cc: benzylisoquinoline
    - they are competitive receptor antagonist
    - all are ionized
    - lack CNS side effect
    - therapeutic use: muscle relaxation
    - reversal of effects of non depolarizing: AChI
    mivacurium chloride non depolarizing NMJ blocker - cc: benzylisoquinoline - they are competitive receptor antagonist - all are ionized - ...
  53. 53—doxacurium chloride
    non depolarizing NMJ blocker
    - cc: benzylisoquinoline
    - they are competitive receptor antagonist
    - all are ionized
    - lack CNS side effect
    - therapeutic use: muscle relaxation
    - reversal of effects of non depolarizing: AChI
    doxacurium chloride non depolarizing NMJ blocker - cc: benzylisoquinoline - they are competitive receptor antagonist - all are ionized - ...
  54. 54—L-TyrosineL-Tyrosine
  55. 55—L-DopaL-Dopa
  56. 56—DopamineDopamine
  57. 57—Norepinephrine
    - released NE :
    binding to receptor postsynaptic and presynaotic
    uptake 1( recycling NE)
    uptake 2 ( degradation, metabolism )
    - receptor selectivity: alpha 1, 2, beta 1
    Norepinephrine - released NE : binding to receptor postsynaptic and presynaotic uptake 1( recycling NE) uptake 2 ( degradation, metabolis...
  58. 58—epinephrine
    - increasing the size of R1 ( CH3)
    increase beta and decrease alpha adrenergic activity
    - receptor activity: Beta 2 > alpha 1,2, beta 1
    epinephrine - increasing the size of R1 ( CH3) increase beta and decrease alpha adrenergic activity - receptor activity: Beta 2 > alph...
  59. 59—Isoproterenol
    increasing the size of R1 (isopropyl)
    increase beta and decrease alpha adrenergic activity
    - receptor activity: Beta 2, Beta 1
    Isoproterenol increasing the size of R1 (isopropyl) increase beta and decrease alpha adrenergic activity - receptor activity: Beta 2, Beta 1
  60. 60—Colterol
    - increase the size of R1 to t-butyl group
    increase selectivity to beta 2 agonistic activity
    -cc: phenylethanolamines
    -receptor selectivity :beta 2 > beta 1
    beta 2 agonist
    Colterol - increase the size of R1 to t-butyl group increase selectivity to beta 2 agonistic activity -cc: phenylethanolamines -receptor ...
  61. 61—ritodrine
    -increasing the size of R1 => increase selectivity to beta 2 agonistic activity
    - at least one hydroxyl group is required to form hydrogen bonding with receptor
    ritodrine -increasing the size of R1 => increase selectivity to beta 2 agonistic activity - at least one hydroxyl group is required to...
  62. 62—Ethylnorepinephrine
    substation on Carbon 2, R2: ethyl
    increase beta activity
    chiral center at C2
    -receptor activity: beta > alpha
    Ethylnorepinephrine substation on Carbon 2, R2: ethyl increase beta activity chiral center at C2 -receptor activity: beta > alpha
  63. 63—alpha- methylnorepinephrine (1R, 2S)
    1R, 2S isomer : maximum direct activity
    1R, 2R isomer: indirect activity
    receptor activity: alpha 2 > alpha 1
    alpha- methylnorepinephrine (1R, 2S) 1R, 2S isomer : maximum direct activity 1R, 2R isomer: indirect activity receptor activity: alpha 2 ...
  64. 64—terbutaline
    3', 5'- dihydroxy substitution: orally active no COMT metabolism
    receptor activity: beta 2> beta 1
    terbutaline 3', 5'- dihydroxy substitution: orally active no COMT metabolism receptor activity: beta 2> beta 1
  65. 65—albuterol
    3' hydroxymethyl,4'hydroxy substitution
    non cathechol => orally active
    receptor activity: beta 2 > beta 1
    albuterol 3' hydroxymethyl,4'hydroxy substitution non cathechol => orally active receptor activity: beta 2 > beta 1
  66. 66—Phenylephrine
    3' hydroxyl substitution => alpha 1 activity
    Phenylephrine 3' hydroxyl substitution => alpha 1 activity
  67. 67—Metaraminol
    3' hydroxyl substitution => alpha 1 activity
    Metaraminol 3' hydroxyl substitution => alpha 1 activity
  68. 68—Methoxamine
    2',5' -dimethoxy substitution => alpha 1 activity
    Methoxamine 2',5' -dimethoxy substitution => alpha 1 activity
  69. 69—pirbuterol
    beta 2 agonist
    cc: phenylethanolamies
    pirbuterol beta 2 agonist cc: phenylethanolamies
  70. 70—salmeterol
    beta 2 agonist
    cc: phenylethanolamines
    salmeterol beta 2 agonist cc: phenylethanolamines
  71. 71—bitolterol
    -beta 2 agonist
    - phenylethanolamine
    - non catechol : orally active
    - bi- toluoylester ( more lipophilic)
    - given by inhalation
    -hydrolyzed by esterase in the lungs to give colterol
    - twice the DOA than catechol
    bitolterol -beta 2 agonist - phenylethanolamine - non catechol : orally active - bi- toluoylester ( more lipophilic) - given by inhalatio...
  72. 72—Dobutamine
    (-) dobutamine : alpha agonist + beta 1 agonist
    (+) dobutamine: alpha antagonist + beta 1 agonist ( 10x)
    racemic mixture: selective beta 1 activity
    exception to SAR
    Dobutamine (-) dobutamine : alpha agonist + beta 1 agonist (+) dobutamine: alpha antagonist + beta 1 agonist ( 10x) racemic mixture: sele...
  73. 73—dopamine
    - not strictly adrenergic agonist
    - DA receptor agonist => dialates renal blood vessels
    - at higher dose acts on beta 1 receptor
    - at much higher dose acts on alpha 1 receptor
    - not orally active
    dopamine - not strictly adrenergic agonist - DA receptor agonist => dialates renal blood vessels - at higher dose acts on beta 1 recep...
  74. 74—(+,-) ephedrine
    - mixed acting sympathomimetics
    - alkaloid from Ephedra species (Ma Huang)
    - non cathechol : orally active
    more lipophilic
    - 1R, 2S: direct + indirect acting
    -used as nasal decongestant
    - cc: phenylethanoloamines
    (+,-) ephedrine - mixed acting sympathomimetics - alkaloid from Ephedra species (Ma Huang) - non cathechol : orally active more lipophili...
  75. 75—pseudoephedrine
    - 1S, 2R and 1S, 2S : indirectly acting sympathomimetics
    pseudoephedrine - 1S, 2R and 1S, 2S : indirectly acting sympathomimetics
  76. 76—amphetamine
    indirectly acting sympathomimetics
    dextro> levo
    non cathechol: orally active
    no hydrolysis: no 0H, very lipophilic, CNS stimulant
    amphetamine indirectly acting sympathomimetics dextro> levo non cathechol: orally active no hydrolysis: no 0H, very lipophilic, CNS st...
  77. 77—metamphetamine
    indirectly acting sympathomimetics
    dextro> levo
    non cathechol: orally active
    no hydrolysis: no 0H, very lipophilic, CNS stimulant
    metamphetamine indirectly acting sympathomimetics dextro> levo non cathechol: orally active no hydrolysis: no 0H, very lipophilic, CNS...
  78. 78—propylhexedrine
    indirectly acting sympathomimetics
    same as metamphetamine
    dextro> levo
    non cathechol: orally active
    no hydrolysis: no 0H, very lipophilic,
    POTENT CNS stimulant
    propylhexedrine indirectly acting sympathomimetics same as metamphetamine dextro> levo non cathechol: orally active no hydrolysis: no ...
  79. 79—xylometazoline
    - alpha 1 adrenergic agonists
    - cc: imidazoline derivatives
    - contain a carbon between C2 of imidazoline and a phenyl ring
    - contain phenylethylamine moiety
    ortho methyl: agonistic activity at alpha 1 and alpha 2 receptors
    - bulky group at para position: increase alpha 1 and decrease alpha 2 activity
    - mainly used as nasal decongestant
    xylometazoline - alpha 1 adrenergic agonists - cc: imidazoline derivatives - contain a carbon between C2 of imidazoline and a phenyl ring...
  80. 80—oxymetazoline
    - alpha 1 adrenergic agonists
    - cc: imidazoline derivatives
    contain a carbon between C2 of imidazoline and a phenyl ring
    - contain phenylethanolamine moiety
    ortho methyl: agonistic activity at alpha 1 and alpha 2 receptors
    - bulky group at para position: increase alpha 1 and decrease alpha 2 activity
    - mainly used as nasal decongestant
    oxymetazoline - alpha 1 adrenergic agonists - cc: imidazoline derivatives contain a carbon between C2 of imidazoline and a phenyl ring - ...
  81. 81—tetrahydrozoline
    alpha 1 adrenergic agonists
    - cc: imidazoline derivatives
    contain a carbon between C2 of imidazoline and a phenyl ring
    - contain phenylethylamine moiety
    ortho methyl: agonistic activity at alpha 1 and alpha 2 receptors
    - mainly used as nasal decongestant
    tetrahydrozoline alpha 1 adrenergic agonists - cc: imidazoline derivatives contain a carbon between C2 of imidazoline and a phenyl ring -...
  82. 82—naphazoline
    alpha 1 adrenergic agonists
    - cc: imidazoline derivatives
    contain a carbon between C2 of imidazoline and a phenyl ring
    - contain phenylethylamine moiety
    ortho methyl: agonistic activity at alpha 1 and alpha 2 receptors
    - mainly used as nasal decongestant
    naphazoline alpha 1 adrenergic agonists - cc: imidazoline derivatives contain a carbon between C2 of imidazoline and a phenyl ring - cont...
  83. 83—clonidine
    - potent alpha 2 adrenergic receptor agonist
    -cc: imidazoline derivatives
    - developed as nasal vasoconstrictor
    - produce marked hypotensive effects, maily centrally mediated throughpostsynaptic alpha2 adrenergic receptor
    - used as antihypertensive agent
    - effects on peripheral postsynaptic alpha 2 receptors: vasoconstriction
    - effects on peripheral presynaptic: negative feedback, decrease NE
    - pka 8.5, 80% ionized, 20% NI
    clonidine - potent alpha 2 adrenergic receptor agonist -cc: imidazoline derivatives - developed as nasal vasoconstrictor - produce marked...
  84. 84—Apraclonidine
    alpha 2 adrenergic agonist
    imidazoline moiety
    Apraclonidine alpha 2 adrenergic agonist imidazoline moiety
  85. 85—brimonidine
    alpha 2 adrenergic agonist
    imidazoline moiety
    brimonidine alpha 2 adrenergic agonist imidazoline moiety
  86. 86—guanabenz
    potent alpha 2 adrenergic agonist
    non imidazoline, clonidine like
    same indication as clonidine
    guanabenz potent alpha 2 adrenergic agonist non imidazoline, clonidine like same indication as clonidine
  87. 87—guanfacine
    potent alpha 2 adrenergic agonist
    non imidazoline, clonidine like
    same indication as clonidine
    guanfacine potent alpha 2 adrenergic agonist non imidazoline, clonidine like same indication as clonidine
  88. 88—alpha -methyldopamine
    alpha 2\ adrenergic antagonist
    non imidazoline derivative
    undergoes bioinactivation
    alpha -methyldopamine alpha 2\ adrenergic antagonist non imidazoline derivative undergoes bioinactivation
  89. 89—phenoxybenzamine
    - adrenergic antagonist
    - irreversible alpha blocker
    - non selective ( alpha 1 and 2 )
    - Beta-haloalkylamine derivative
    - slow onset of action: because it is a prodrug, must undergoe bioactivation
    ( alkylated receptor active )
    -limited use in pheochromocytoma (cancer of adrenal medulla)
    phenoxybenzamine - adrenergic antagonist - irreversible alpha blocker - non selective ( alpha 1 and 2 ) - Beta-haloalkylamine derivative ...
  90. 90—tolazoline
    - adrenergic receptor antagonist
    - reversible
    - non selective ( blocks alpha 1 and 2 )
    - similar to xylometazoline BUT no ortho substitution: no alpha agonistic effects
    - limited use in treatment of symptoms of pheochromocytoma
    - rapid onset of action
    tolazoline - adrenergic receptor antagonist - reversible - non selective ( blocks alpha 1 and 2 ) - similar to xylometazoline BUT no orth...
  91. 91—phentolamine
    - adrenergic receptor antagonist
    - reversible
    - non selective ( blocks alpha 1 and 2 )
    - limited use in treatment of symptoms of pheochromocytoma
    - rapid onset of action
    phentolamine - adrenergic receptor antagonist - reversible - non selective ( blocks alpha 1 and 2 ) - limited use in treatment of symptom...
  92. 92—prazosin
    - selective alpha 1 receptor antagonist
    reversible
    - quinazoline derivative
    -contain 4-amoni-6-7-dimethoxyquinazoline ring connected to piperazine at C2
    -lower Blood Pressure
    prazosin - selective alpha 1 receptor antagonist reversible - quinazoline derivative -contain 4-amoni-6-7-dimethoxyquinazoline ring conne...
  93. 93—terazosin
    selective alpha 1 receptor antagonist
    reversible
    - quinazoline derivative
    -contain 4-amoni-6-7-dimethoxyquinazoline ring connected to piperazine at C2
    -lower Blood Pressure
    terazosin selective alpha 1 receptor antagonist reversible - quinazoline derivative -contain 4-amoni-6-7-dimethoxyquinazoline ring connec...
  94. 94—doxazosin
    selective alpha 1 receptor antagonist
    reversible
    - quinazoline derivative
    -contain 4-amoni-6-7-dimethoxyquinazoline ring connected to piperazine at C2
    -lower Blood Pressure
    doxazosin selective alpha 1 receptor antagonist reversible - quinazoline derivative -contain 4-amoni-6-7-dimethoxyquinazoline ring connec...
  95. 95—tamsulosin
    selective alpha 1 receptor antagonist
    reversible
    high affinity to alpha 1 A subtype present in prostate gland => used to treat BHP ( benign prostatic hyperplasia)
    - cc: sulfonamide phenylpropylamine
    tamsulosin selective alpha 1 receptor antagonist reversible high affinity to alpha 1 A subtype present in prostate gland => used to tr...
  96. 96—indoramin
    - reversible selective alpha 1 receptor antagonist and H1 (histamine) and 5receptor antagonistHT (serotonin)
    - indole derivative
    indoramin - reversible selective alpha 1 receptor antagonist and H1 (histamine) and 5receptor antagonistHT (serotonin) - indole derivative
  97. 97—yohimbine
    - reversible selective alpha 2 blocker
    - indole alkaloid from Yohimbe bark
    - increase Blood Pressure AND Heart Rate
    - very limited use to treat male sexual impotency
    yohimbine - reversible selective alpha 2 blocker - indole alkaloid from Yohimbe bark - increase Blood Pressure AND Heart Rate - very limi...
  98. 98—practolol
    - Beta adrenergic receptor antagonist
    - aryloxypropanolamine with p-acylamino
    -change of acylamino to ortho or meta => loss of selectivity
    - inhibited isoproterenol induced tachycardia with minimal effects on isoproterenol induced hypotension
    -withdrawn from the market due to visual loss
    practolol - Beta adrenergic receptor antagonist - aryloxypropanolamine with p-acylamino -change of acylamino to ortho or meta => loss ...
  99. 99—pronethalol
    - beta adrenergic receptor antagonist non selective
    -arylethanolamine
    - no partial agonistic activity
    - carcinogenic in animals
    pronethalol - beta adrenergic receptor antagonist non selective -arylethanolamine - no partial agonistic activity - carcinogenic in animals
  100. 100—propranolol
    -aryloxypropanolamine
    -beta adrenergic receptor non selective
    -10X> potent
    -no partial agonistic activity
    -not carcinogenic
    - used in hypertension, agnia pectoris, arrhythmia, migraine
    propranolol -aryloxypropanolamine -beta adrenergic receptor non selective -10X> potent -no partial agonistic activity -not carcinogeni...
  101. 101—bunolol
    -non selective beta adrenergic receptor antagonist
    bunolol -non selective beta adrenergic receptor antagonist
  102. 102—carteolol
    -non selective beta adrenergic receptor antagonist
    carteolol -non selective beta adrenergic receptor antagonist
  103. 103—metipranolol
    -non selective beta adrenergic receptor antagonist
    - exception para postion
    - ester hydrolysis=> short acting
    metipranolol -non selective beta adrenergic receptor antagonist - exception para postion - ester hydrolysis=> short acting
  104. 104—nadolol
    -non selective beta adrenergic receptor antagonist
    nadolol -non selective beta adrenergic receptor antagonist
  105. 105—penbutolol
    -non selective beta adrenergic receptor antagonist
    penbutolol -non selective beta adrenergic receptor antagonist
  106. 106—pindolol
    -non selective beta adrenergic receptor antagonist
    pindolol -non selective beta adrenergic receptor antagonist
  107. 107—sotalol
    -non selective beta adrenergic receptor antagonist
    - aryl sulfonamide ethanolamine derivative
    sotalol -non selective beta adrenergic receptor antagonist - aryl sulfonamide ethanolamine derivative
  108. 108—timolol
    -non selective beta adrenergic receptor antagonist
    timolol -non selective beta adrenergic receptor antagonist
  109. 109—acebutolol
    -selective beta 1 adrenergic receptor antagonist
    cardio slective
    acebutolol -selective beta 1 adrenergic receptor antagonist cardio slective
  110. 110—atenolol
    -selective beta 1 adrenergic receptor antagonist
    cardio slective
    atenolol -selective beta 1 adrenergic receptor antagonist cardio slective
  111. 111—betaxolol
    - selective beta 1 adrenergic receptor antagonist
    cardio selective
    betaxolol - selective beta 1 adrenergic receptor antagonist cardio selective
  112. 112—esmolol
    - selective beta 1 adrenergic receptor antagonist
    cardio slective
    esmolol - selective beta 1 adrenergic receptor antagonist cardio slective
  113. 113—metoprolol
    selective beta 1 adrenergic receptor antagonist
    cardio slective
    metoprolol selective beta 1 adrenergic receptor antagonist cardio slective
  114. 114—bisoprolol
    selective beta 1 adrenergic receptor antagonist
    cardio slective
    bisoprolol selective beta 1 adrenergic receptor antagonist cardio slective
  115. 115—labetolol
    non selective beta blocker and alpha 1 blocker
    mixed acting
    labetolol non selective beta blocker and alpha 1 blocker mixed acting
  116. 116—carvedilol
    non selective beta blocker and alpha 1 blocker
    mixed acting
    carvedilol non selective beta blocker and alpha 1 blocker mixed acting
  117. 117—metyrosine
    - drugs affecting NE biosynthesis
    - tyrosine hydroxylase inhibitor
    metyrosine - drugs affecting NE biosynthesis - tyrosine hydroxylase inhibitor
  118. 118—carbidopa
    - drugs affecting NE biosynthesis
    - L-Dopa decarboxylase inhibitor
    carbidopa - drugs affecting NE biosynthesis - L-Dopa decarboxylase inhibitor
  119. 119—reserpine
    -drugs affecting NE storage
    ( catecholamine depleting agents)
    - indole alkaloid
    -isolated from Rauwolfa Serpentina
    - inhibit catecholamine storage in storage vesicle => depletion of catecholamines
    reserpine -drugs affecting NE storage ( catecholamine depleting agents) - indole alkaloid -isolated from Rauwolfa Serpentina - inhibit ca...
  120. 120—guanadrel
    - drugs affecting NE release ( adrenergic neuronal blocking agents)
    guanadrel - drugs affecting NE release ( adrenergic neuronal blocking agents)
  121. 121—guanethidine
    - drugs affecting NE release ( adrenergic neuronal blocking agents)
    guanethidine - drugs affecting NE release ( adrenergic neuronal blocking agents)
  122. 122—bretylium
    - drugs affecting NE release ( adrenergic neuronal blocking agents)
    bretylium - drugs affecting NE release ( adrenergic neuronal blocking agents)
  123. 123—ergot alkaloid
    - produced by calviceps purourea, a fungus that infects grains
    ergot alkaloid - produced by calviceps purourea, a fungus that infects grains
  124. 124—ergotamine
    - ergot alkaloid
    - produced by calviceps purourea, a fungus that infects grains
    -mixed agonist/ antagonist
    - potent smooth muscle contraction
    - also used for migraine treatment
    ergotamine - ergot alkaloid - produced by calviceps purourea, a fungus that infects grains -mixed agonist/ antagonist - potent smooth mus...
  125. 125—ergonovine
    -ergot alkaloid
    -mixed agonist/ antagonist
    - potent smooth muscle contraction
    - also used for migraine treatment
    - potent inducer of uterine
    - because of better bioavailability, used to replace ergotmaine
    ergonovine -ergot alkaloid -mixed agonist/ antagonist - potent smooth muscle contraction - also used for migraine treatment - potent indu...
  126. 126—methylergonovine
    -ergot alkaloid
    -mixed agonist/ antagonist
    - potent smooth muscle contraction
    - also used for migraine treatment
    - potent inducer of uterine
    - because of better bioavailability, used to replace ergotmaine
    methylergonovine -ergot alkaloid -mixed agonist/ antagonist - potent smooth muscle contraction - also used for migraine treatment - poten...
  127. 127—methylseregide
    -ergot alkaloid
    -mixed agonist/ antagonist
    -mainly used for migraine treatment
    methylseregide -ergot alkaloid -mixed agonist/ antagonist -mainly used for migraine treatment
  128. 128—morphine
    - cc: phenantrene
    - teriary amine group,
    N-methyl: good agonist
    Removal of N-methyl: decrease activity
    increase size of alkyl group: antagonist
    morphine - cc: phenantrene - teriary amine group, N-methyl: good agonist Removal of N-methyl: decrease activity increase size of alkyl gr...
  129. 129—phenanthrenephenanthrene
  130. 130—benzoquinone
    -oxidation od morphine product
    benzoquinone -oxidation od morphine product
  131. 131—codeine
    - weak mu agonist
    - potent antitussive agent
    -partial O-demethylated => morphine
    codeine - weak mu agonist - potent antitussive agent -partial O-demethylated => morphine
  132. 132—Heroin
    -3,6-diacetyl derivative of morphine
    - weak affinity to mu receptor
    -more lipophilic: penetrates BBB
    - hydrolyzed in the brain to give:
    3-acetylmorphine (3-MAM)
    6-acetylmorphine (6-MAM)
    - 6-MAM has potent mu agonist
    Heroin -3,6-diacetyl derivative of morphine - weak affinity to mu receptor -more lipophilic: penetrates BBB - hydrolyzed in the brain to ...
  133. 133—oxymorphone
    - 3-hydroxy-N-methyl derivative 10X as potent as morphine
    - 14 beta hydroxyl enhances mu agonist activity and decrease antitussive activity
    oxymorphone - 3-hydroxy-N-methyl derivative 10X as potent as morphine - 14 beta hydroxyl enhances mu agonist activity and decrease antitu...
  134. 134—oxycodone
    -3-hydroxyl-N-methyl derivative same activity as morphine but better oral bioavailability
    - 14 beta hydroxyl enhances mu agonist activity and decrease antitussive activity
    oxycodone -3-hydroxyl-N-methyl derivative same activity as morphine but better oral bioavailability - 14 beta hydroxyl enhances mu agonis...
  135. 135—naloxone
    - N-allyl oxymorphone
    - pure non selective opioid receptor antagonist
    naloxone - N-allyl oxymorphone - pure non selective opioid receptor antagonist
  136. 136—nalorphine
    - N-allyl substitution for N-methyl 7,8-double bond reduction 6-keto reduction
    u
    nalorphine - N-allyl substitution for N-methyl 7,8-double bond reduction 6-keto reduction u
  137. 137—morphinan
    - removal of 4,5 epoxide bridge
    (modification of E ring)
    morphinan - removal of 4,5 epoxide bridge (modification of E ring)
  138. 138—levorphanol
    -removal of 4,5 epoxide bridge
    - 8X more potent mu receptor agonist
    levorphanol -removal of 4,5 epoxide bridge - 8X more potent mu receptor agonist
  139. 139—butorphanol
    -removal of 4,5 epoxide bridge
    - mu antagonist and kappa agonist
    butorphanol -removal of 4,5 epoxide bridge - mu antagonist and kappa agonist
  140. 140—dextromethorphan
    -removal of 4,5 epoxide bridge
    (+) levorphanol = dextrophan
    - lacks analgesia
    - antitussive activity
    dextromethorphan -removal of 4,5 epoxide bridge (+) levorphanol = dextrophan - lacks analgesia - antitussive activity
  141. 141—benzomorphans
    - lacks the epoxide ring and the C ring
    - retain opioid activity
    benzomorphans - lacks the epoxide ring and the C ring - retain opioid activity
  142. 142—cyclazocine
    - R: N-cyclopropyl methyl
    - mixed agonist/ antagonist
    kappa agonist
    mu antagonist
    cyclazocine - R: N-cyclopropyl methyl - mixed agonist/ antagonist kappa agonist mu antagonist
  143. 143—phenazocine
    - R: N-ethylphenyl
    -potent mu agonist about 10X> morphine
    phenazocine - R: N-ethylphenyl -potent mu agonist about 10X> morphine
  144. 144—pentazocine
    -R: N-methyl of 2-methyl-2-butene
    - mixed agonist/antagonist
    kappa agonistic activity: analgesic
    mu antagonistic activity
    -only one marketed in US
    pentazocine -R: N-methyl of 2-methyl-2-butene - mixed agonist/antagonist kappa agonistic activity: analgesic mu antagonistic activity -on...
  145. 145—metazocine
    -R: CH3
    - mu agonist
    -metasocine > morphine
    metazocine -R: CH3 - mu agonist -metasocine > morphine
  146. 146—meperidine
    - A and D ring analogs of morphine
    - cc: phenylpiperidine
    -first synthesized agent with mu agonist activity of 1/4 of morphine
    -short DOA (useful in some medical procedure)
    meperidine - A and D ring analogs of morphine - cc: phenylpiperidine -first synthesized agent with mu agonist activity of 1/4 of morphine...
  147. 147—MPTP
    1-methyl-4-phenyl-1,2,3,6-tetrahydropyridine
    -damages DA neurons => parkinsonism
    - product of reversed ester of meperidine
    MPTP 1-methyl-4-phenyl-1,2,3,6-tetrahydropyridine -damages DA neurons => parkinsonism - product of reversed ester of meperidine
  148. 148—fentanyl
    - cc: anilidopiperidine
    - 80X> potent than morphine
    fentanyl - cc: anilidopiperidine - 80X> potent than morphine
  149. 149—sufentanil
    - cc: anilidopiperidine
    - 10X> potent than fentanyl (fentanyl 80X> morphine)
    sufentanil - cc: anilidopiperidine - 10X> potent than fentanyl (fentanyl 80X> morphine)
  150. 150—remifentanyl
    - cc: anilidopiperidine
    - 25X> potent than morphine
    remifentanyl - cc: anilidopiperidine - 25X> potent than morphine
  151. 151—alfentanil
    - cc: anilidopiperidine
    - 20X> potent than morphine
    alfentanil - cc: anilidopiperidine - 20X> potent than morphine
  152. 152—methadone
    -cc: diphenylheptanone
    - orally active and long DOA
    - useful for maintenance therapy of opoids addicts and for pain suppression of terminally ill patients
    methadone -cc: diphenylheptanone - orally active and long DOA - useful for maintenance therapy of opoids addicts and for pain suppression...
  153. 153—isomethadoneisomethadone
  154. 154—diphenoxylate
    -cc: diphenylheptanone
    - structural modification of methadone
    -antidiarrheal opioids
    diphenoxylate -cc: diphenylheptanone - structural modification of methadone -antidiarrheal opioids
  155. 155—loperamide
    -cc: diphenylheptanone
    - structural modification of methadone
    -antidiarrheal opioids
    loperamide -cc: diphenylheptanone - structural modification of methadone -antidiarrheal opioids
  156. 156—thebaine
    -oripavine derivative
    - from papaver bracteatum
    no activity as opioid agonist
    thebaine -oripavine derivative - from papaver bracteatum no activity as opioid agonist
  157. 157—etorphine
    - oripavine derivative
    - 1000 X> morphine
    - severe respiratory depression
    -low therapeutic index in humans, used for veterinary medicine
    etorphine - oripavine derivative - 1000 X> morphine - severe respiratory depression -low therapeutic index in humans, used for veterin...
  158. 158—buprenorphine
    -orpavine derivative
    - 20-50X> morphine
    - mixed agonist / antagonist
    -does not produce tolerance and addiction
    buprenorphine -orpavine derivative - 20-50X> morphine - mixed agonist / antagonist -does not produce tolerance and addiction
  159. 159—tramadol
    - synthetic mu agonist
    - orally active
    - possess opioid and non opioid analgesic activity
    -analgesic not reversed by naloxone
    -O-dimethyl metabolite is 6X> parent drug
    -less respiratory depression than morphine
    tramadol - synthetic mu agonist - orally active - possess opioid and non opioid analgesic activity -analgesic not reversed by naloxone -O...
  160. 160—dezocine
    -mixed agonist / antagonist
    -only primary amine opoid agent
    - exact receptor selectivity is not known
    - equipotent with morphine
    dezocine -mixed agonist / antagonist -only primary amine opoid agent - exact receptor selectivity is not known - equipotent with morphine
  161. 161—nalbuphine
    - N-cyclobutylmethyl substitution for N-methyl 7,8-double bond reduction 6 keto reduction
    -mu antagonist and kappa agonist
    nalbuphine - N-cyclobutylmethyl substitution for N-methyl 7,8-double bond reduction 6 keto reduction -mu antagonist and kappa agonist
  162. 162—naltrexone
    -N-cyclopropyl-methyl oxymorphone
    - pure non selective opioid antagonist
    naltrexone -N-cyclopropyl-methyl oxymorphone - pure non selective opioid antagonist

Informationen

Beschreibung
Karteikarten am untitled 2, erstellt von lola_smily am 22/06/2015.
Erstellt von
lola_smily
Aufrufe
2.277
Bewertung
Durchschnittliche Bewertung 5,0 von 5 (2 Bewertungen)

Feedback

Worum geht es?

Wie gefällt dir das neue Design?

Dein Eindruck